function at = AsymmetricTop(AT)
% SymmetricTop SymmetricTop class constructor.
% at = SymmetricTop(RB) creates a SymmetricTop object from structure AT.

if nargin == 0
   at.m = [];
   at.a = [];
   at.b = [];
   at.c = [];
   rb = RigidBody();
   at = class(at,'AsymmetricTop',rb);      
else
   if (isa(AT, 'AsymmetricTop'))
      at = AT; 
   else

   at.m = AT.m;
   at.a = AT.a;
   at.b = AT.b;
   at.c = AT.c;     
    
   rb = RigidBody();
   
   pmx = at.m*(at.b*at.b + at.c*at.c) / 12;
   pmy = at.m*(at.c*at.c + at.a*at.a) / 12;
   pmz = at.m*(at.a*at.a + at.b*at.b) / 12;
   pmi = [ pmx, pmy, pmz ];
   
   rb = set_rb(rb, 'pmi', pmi);   
   
   faces = [ 1 2 3; 1 3 4; 3 4 8; 4 5 8; 5 6 8; 6 7 8; 1 2 7; 1 6 7; 1 5 6; 1 4 5; 2 3 8; 2 7 8 ];

   x = at.a / 2 ;
   y = at.b / 2 ;
   z = at.c / 2 ;
   
   vertices = [ x, y, -z ; ...
                      x, y, z ; ...
                      x, -y, z ; ...
                      x, -y, -z ; ...
                     -x, -y, -z ; ...
                      -x, y, -z ; ...
                      -x, y, z ; ...
                      -x, -y, z ; ];    

   colors = [ 1 0 0; 1 0 0; 0 1 0; 0 1 0; 1 0 0; 1 0 0; 0 1 0; 0 1 0; 0 0 1; 0 0 1; 0 0 1; 0 0 1 ];
   
   rb = set_rb(rb, 'Vertices', vertices);
   rb = set_rb(rb, 'Faces', faces);
   rb = set_rb(rb, 'Colors', colors);
      
   at = class(at, 'AsymmetricTop', rb);  

   end

   
   
end