function at = set_at(at, TOP)
    
   at.m = TOP.m;
   at.a = TOP.a;
   at.b = TOP.b;
   at.c = TOP.c;    
   
   at = set_rb(at, 'T', TOP.T);
   at = set_rb(at, 'dt', TOP.dt);
   at = set_rb(at, 'n', TOP.n);
   at = set_rb(at, 'theta', TOP.theta); 
   at = set_rb(at, 'phi', TOP.phi); 
   at = set_rb(at, 'psi', TOP.psi); 
   at = set_rb(at, 'dtheta', TOP.dtheta); 
   at = set_rb(at, 'dphi', TOP.dphi); 
   at = set_rb(at, 'dpsi', TOP.dpsi); 
   
   at = set_rb(at, 'rc', TOP.rc); 
   at = set_rb(at, 'g', TOP.g); 
   
   at = set_rb(at, 'm', TOP.m); 
      
   p = TOP.rc;   
      
   theta = TOP.theta;
   phi = TOP.phi;
   psi = TOP.psi;

   dtheta = TOP.dtheta;
   dphi = TOP.dphi;
   dpsi = TOP.dpsi;
   
   q0 = [ dphi * sin(theta) * sin(psi) + dtheta * cos(psi),...
              dphi * sin(theta) * cos(psi) - dtheta * sin(psi),...
              dphi * cos(theta) + dpsi ];
          
   at = set_rb(at, 'q0',  q0 );
   
   Aphi = [ [cos(phi) -sin(phi) 0];[sin(phi) cos(phi) 0];[0 0 1] ];
   Atheta = [ [1 0 0];[0 cos(theta) -sin(theta)];[0 sin(theta) cos(theta)] ];
   Apsi = [ [cos(psi) -sin(psi) 0];[sin(psi) cos(psi) 0];[0 0 1] ];

   A = Aphi * Atheta *  Apsi ;
   
   A = A';   
   
   at = set_rb(at, 'rm0',  A );
   
   x = at.a / 2 ;
   y = at.b / 2 ;
   z = at.c / 2 ;
   
   vertices = [ x, y, -z ; ...
                      x, y, z ; ...
                      x, -y, z ; ...
                      x, -y, -z ; ...
                     -x, -y, -z ; ...
                      -x, y, -z ; ...
                      -x, y, z ; ...
                      -x, -y, z ; ];      
                  
   vertices = vertices + repmat(p,8,1) ;
   
   at = set_rb(at, 'Vertices', vertices);
      
   vertices = vertices * A; 
   
   yf = get_rb(at, 'Faces' );
   yv = vertices;
   yc = get_rb(at, 'Colors' );
    
   p1 = [ 0, 0, 0];
   p2 = [ p(1), p(2), p(3)];  
   
   p1 = p1 * A ;
   p2 = p2 * A ;
   
   M = cat(1, p1, p2);    
   
   x = M(:,1);
   y = M(:,2);
   z = M(:,3); 

   ax =  get(RBInterface,'CurrentAxes');
   cla(ax, 'reset');
   
   patch('Faces', yf, 'Vertices', yv, 'FaceVertexCData', yc, ...
    'FaceColor','flat');

   line('XData',x,'YData',y,'ZData',z,'Color', [0 0 0], 'LineWidth',1, 'LineStyle','--');

   q0_p1 = [ 0 0 0 ]; 
   q0_p2 = q0 * A;
   coef = norm(q0_p2);
   if coef ~= 0
       q0_p2 = q0_p2 / coef;
       q0_p2 = 1000 * q0_p2;
   end
       
   q0_points = [ q0_p1; q0_p2 ];
   
   x = q0_points(:,1);
   y = q0_points(:,2);
   z = q0_points(:,3);   
   
   line('XData',x,'YData',y,'ZData',z,'Color', [0 1 1], 'LineWidth',2);

   set(get(ax,'XLabel'),'String','X');
   set(get(ax,'YLabel'),'String','Y');
   set(get(ax,'ZLabel'),'String','Z');
   
   view(3); grid on; 
   set(ax, 'xlim', [-2 2] );
   set(ax, 'ylim', [-2 2] );
   set(ax, 'zlim', [-3 3] ); 
   
   pmx = at.m*(at.b*at.b + at.c*at.c) / 12;
   pmy = at.m*(at.c*at.c + at.a*at.a) / 12;
   pmz = at.m*(at.a*at.a + at.b*at.b) / 12;
   pmi = [ pmx, pmy, pmz ]; 
   
   at = set_rb(at, 'pmi', pmi);  
   
   handle_ = findobj('Tag','popupmenu1');
   popup_sel_index = get(handle_, 'Value');
   if popup_sel_index == 7
       check = dphi^2 - 4 * (pmx + TOP.m * (norm(TOP.rc))^2 ) * TOP.m * TOP.g * norm(TOP.rc) / pmz^2;
       if check > 0 
          RBMessage_to_CommandWindow = 'The rotation about the vertical axis is stable.\n';
       else
          RBMessage_to_CommandWindow = 'The rotation about the vertical axis is not stable.\n';       
       end       

       RBMessage_to_CommandWindow = strcat(RBMessage_to_CommandWindow,...
           'The stability depends on the value of dphi. \n', ...
           'The more abs(dphi) the more stable the rotation about the vertical axis will be.');
       
       RBMessage_to_CommandWindow = sprintf(RBMessage_to_CommandWindow)
       
   end
   

end