function rb = RigidBody(RB)
% RigidBody RigidBody class constructor.
% rb = RigidBody(RB) creates a RigidBody object from structure RB.
% Author: Ferat Talat oglu

if nargin == 0
    
   rb.T = []; % time interval
   rb.dt = []; % step
   rb.n = []; % floor(T/dt);
   rb.theta = []; % 1 double; initial theta
   rb.phi = []; % 1 double; initial phi
   rb.psi = []; % 1 double; initial psi
   rb.dtheta = []; % 1 double; initial velocity of theta
   rb.dphi = []; % 1 double; initial velocity of phi
   rb.dpsi = []; % 1 double; initial velocity of psi
   rb.q0 = []; % 3 double; initial angular velocity
   rb.m = []; %mass of the rigid body
   rb.pmi = []; % 3 double; principal moments of inertia
   rb.g = []; % 1 double; gravitational acceleration
   rb.rc = []; % 3 double; center of mass in the Lab systm  
   rb.rm = []; % 16*N double; array of rotation matrixes for animation
   rb.fr = []; % 1 double; frame number of animation
   rb.rm0 = [];  % 16 double; rotation matrix rb.rm0 = rb.rm(0)
   rb.vertices = [];
   rb.faces = [];
   rb.colors = [];
   rb.hgo = []; % hgtransform graphics object
   rb.gobjects = []; % graphics objects
   
   rb = class(rb,'RigidBody');
   
elseif isa(RB,'RigidBody') 
   rb = RB;
else
   
   rb.T = RB.t; % time interval 
   rb.dt = RB.dt; % step
   rb.n = RB.n; % floor(T/dt);
   rb.theta = RB.theta; % 1 double; initial theta
   rb.phi = RB.phi; % 1 double; initial phi
   rb.psi = RB.psi; % 1 double; initial psi
   rb.dtheta = RB.dtheta; % 1 double; initial velocity of theta
   rb.dphi = RB.dphi; % 1 double; initial velocity of phi
   rb.dpsi = RB.dpsi; % 1 double; initial velocity of psi
   rb.q0 = RB.q0; % 3 double; initial angular velocity
   rb.m = RB.m; %mass of the rigid body
   rb.pmi = RB.pmi; % 3 double; principal moments of inertia
   rb.g = RB.g; % 1 double; gravitational acceleration
   rb.rc = RB.rc; % 3 double; center of mass in the Lab systm  
   rb.rm = RB.rm; % 16*N double; array of rotation matrixes for animation
   rb.fr = RB.fr; % 1 double; frame number of animation
   rb.rm0 = RB.rm0;  % 16 double; rotation matrix rb.rm0 = rb.rm(0)
   rb.vertices = RB.vertices;
   rb.faces = RB.faces;
   rb.colors = RB.colors;
   rb.hgo = RB.hgo; % hgtransform graphics object
   rb.gobjects = RB.gobjects; % graphics objects
   
   rb = class(rb,'RigidBody');
   
end
