function st = SymmetricTop(ST)
% SymmetricTop SymmetricTop class constructor.
% st = SymmetricTop(RB) creates a SymmetricTop object from structure ST.

    if nargin == 0
       st.md = [];
       st.mL = [];
       st.L = [];
       st.d = [];
       rb = RigidBody();
       st = class(st,'SymmetricTop',rb);      
    else
        if (isa(ST, 'SymmetricTop'))
            st = ST; 
        else
           st.md = ST.md;
           st.mL = ST.mL;
           st.L = ST.L;
           st.d = ST.d;    

           rb = RigidBody();

           pmx = st.mL * st.L^2 / 12 + st.md * st.d^2 / 16;
           pmy = pmx;
           pmz = st.md * st.d^2 / 8;
           pmi = [ pmx, pmy, pmz ];
           rb = set_rb(rb, 'pmi', pmi);
           rb = set_rb(rb, 'r0', st.L / 2 );   

           faces(30,:) = [ 31 2 1];

           for k = 2:30
           faces(k-1,:) = [k k+1 1];
           end

           i = 0:29;
           s = i * (2*pi/30);

           vertices = [ (ST.d / 2) * sin(s); (ST.d / 2) * cos(s); zeros(1,30)]';
           vertices = [[0 0 0]; vertices];   

           colors(30,:) = [0 0 1];

           for k = 1:10
           colors(k,:) = [1 0 0];
           end
           for k = 11:20
           colors(k,:) = [0 1 0];
           end
           for k = 21:29
           colors(k,:) = [0 0 1];
           end

           rb = set_rb(rb, 'Vertices', vertices);
           rb = set_rb(rb, 'Faces', faces);
           rb = set_rb(rb, 'Colors', colors);

           st = class(st, 'SymmetricTop', rb);  

        end   
   
    end

end