function st = set_st(st, TOP)
    
   st.md = TOP.md;
   st.mL = TOP.mL;
   st.d = TOP.d;
   st.L = TOP.L;    
   
   st = set_rb(st, 'T', TOP.T); 
   st = set_rb(st, 'dt', TOP.dt); 
   st = set_rb(st, 'n', TOP.n); 
   st = set_rb(st, 'theta', TOP.theta); 
   st = set_rb(st, 'phi', TOP.phi); 
   st = set_rb(st, 'psi', TOP.psi); 
   st = set_rb(st, 'dtheta', TOP.dtheta); 
   st = set_rb(st, 'dphi', TOP.dphi); 
   st = set_rb(st, 'dpsi', TOP.dpsi); 
   
   st = set_rb(st, 'rc', TOP.rc); 
   st = set_rb(st, 'g', TOP.g); 
   
   st = set_rb(st, 'm', TOP.md + TOP.mL);
      
   p = TOP.rc;
      
   theta = TOP.theta;
   phi = TOP.phi;
   psi = TOP.psi;

   dtheta = TOP.dtheta;
   dphi = TOP.dphi;
   dpsi = TOP.dpsi;
   
   q0 = [ dphi * sin(theta) * sin(psi) + dtheta * cos(psi),...
              dphi * sin(theta) * cos(psi) - dtheta * sin(psi),...
              dphi * cos(theta) + dpsi ];

   st = set_rb(st, 'q0',  q0 );  
   
   Aphi = [ [cos(phi) -sin(phi) 0];[sin(phi) cos(phi) 0];[0 0 1] ];
   Atheta = [ [1 0 0];[0 cos(theta) -sin(theta)];[0 sin(theta) cos(theta)] ];
   Apsi = [ [cos(psi) -sin(psi) 0];[sin(psi) cos(psi) 0];[0 0 1] ];
   
   A = Aphi * Atheta *  Apsi ;
   
   A = A';
   
   st = set_rb(st, 'rm0',  A );   
   
   i = 0:29;
   s = i * (2*pi/30);
         
   vertices = [(st.d / 2) * sin(s) + p(1); (st.d / 2) * cos(s) + p(2); zeros(1,30) + p(3)]';
   vertices = [[0 + p(1), 0 + p(2), 0 + p(3)]; vertices] ;
   
   st = set_rb(st, 'Vertices', vertices);
     
   vertices = vertices * A;
   
   yf = get_rb(st, 'Faces' );
   yv = vertices;
   yc = get_rb(st, 'Colors' );
     
   p1 = [ p(1), p(2), -st.L / 2 + p(3)];
   p2 = [ p(1), p(2), st.L / 2 + p(3)];  
   
   p1 = p1 * A ;
   p2 = p2 * A ;
   
   M = cat(1, p1, p2);    
   
   x = M(:,1);
   y = M(:,2);
   z = M(:,3);
   
   ax =  get(RBInterface,'CurrentAxes');
 
   cla(ax, 'reset');
   
   patch('Faces', yf, 'Vertices', yv, 'FaceVertexCData', yc, ...
                'FaceColor','flat', 'LineStyle', 'none');
            
   line('XData',x,'YData',y,'ZData',z,'Color', [0 0 0], 'LineWidth',2);
    
   p1 = [ 0, 0, 0];
   p2 = [ p(1), p(2), p(3)];  
   
   p2 = p2 * A ;
   
   M = cat(1, p1, p2);    
   
   x = M(:,1);
   y = M(:,2);
   z = M(:,3); 
    
   line('XData',x,'YData',y,'ZData',z,'Color', [0 0 0], 'LineWidth',1, 'LineStyle','--');

   q0_p1 = [ 0 0 0 ]; 
   q0_p2 =  q0*A;
   coef = norm(q0_p2);
   big_number = 1000;
   if coef ~= 0
       q0_p2 = q0_p2 / coef;
       q0_p2 =  big_number * q0_p2;
   end
       
   q0_points = [ q0_p1; q0_p2 ];
   
   x = q0_points(:,1);
   y = q0_points(:,2);
   z = q0_points(:,3);   
   
   line('XData',x,'YData',y,'ZData',z,'Color', [0 1 1], 'LineWidth',2);
   
   set(get(ax,'XLabel'),'String','X');
   set(get(ax,'YLabel'),'String','Y');
   set(get(ax,'ZLabel'),'String','Z');
   
   view(3); grid on; 
   set(ax, 'xlim', [-2 2] );
   set(ax, 'ylim', [-2 2] );
   set(ax, 'zlim', [-3 3] );
   
   pmx = st.mL * st.L^2 / 12 + st.md * st.d^2 / 16;
   pmy = pmx;
   pmz = st.md * st.d^2 / 8;
   pmi = [ pmx, pmy, pmz ];
   st = set_rb(st, 'pmi', pmi); 
   
   handle_ = findobj('Tag','popupmenu1');
   popup_sel_index = get(handle_, 'Value');
   switch popup_sel_index
       case 8           
           m = st.md + st.mL;
           d = norm(p);
           L = (pmx + m * d^2) / (m * d);
           A = pi -  theta;
           
           fun = @(x) 1./sqrt(sin(A*0.5).^2 - sin(x*0.5).^2);

           T = 2 * sqrt(L/9.81) * quadgk(fun,0,A)

           RBMessage_to_CommandWindow = ...
               'T is the period of the pendulum.'           
       case 10
           dpsi = get_rb(st, 'dpsi') 
           RBMessage_to_CommandWindow = ...
               'To see the light effect turn the real-time effect on\nand set dpsi to 2 * pi * fpsRate / 3  .'  ;         
           RBMessage_to_CommandWindow = sprintf(RBMessage_to_CommandWindow)

           
   end
         

end